@@ -50,6 +50,15 @@ def contains(array, *args):
     return False
 
 
+def copy(entries):
+    result = list()
+
+    for entry in entries:
+        result.append(entry)
+
+    return result
+
+
 def to_list(entries):
     if isinstance(entries, list):
         return entries
